@@ -1,4 +1,6 @@
+import html
 import json
+import re
 from copy import deepcopy
 
 from .types import (
@@ -298,13 +300,13 @@ def extract_account(data):
 
 def extract_hashtag_gql(data):
     data["media_count"] = data.get("edge_hashtag_to_media", {}).get("count")
-    data["profile_pic_url"] = data["profile_pic_url"] or None
+    data["profile_pic_url"] = data.get("profile_pic_url") or None
     return Hashtag(**data)
 
 
 def extract_hashtag_v1(data):
     data["allow_following"] = data.get("allow_following") == 1
-    data["profile_pic_url"] = data["profile_pic_url"] or None
+    data["profile_pic_url"] = data.get("profile_pic_url") or None
     return Hashtag(**data)
 
 
@@ -328,7 +330,7 @@ def extract_story_v1(data):
     ]
     story["locations"] = []
     story["hashtags"] = []
-    story["stickers"] = []
+    story["stickers"] = data.get('story_link_stickers') or []
     feed_medias = []
     story_feed_medias = data.get('story_feed_media') or []
     for feed_media in story_feed_medias:
@@ -393,4 +395,8 @@ def extract_highlight_v1(data):
 
 
 def extract_track(data):
+    data['cover_artwork_uri'] = data.get('cover_artwork_uri') or None
+    data['cover_artwork_thumbnail_uri'] = data.get('cover_artwork_thumbnail_uri') or None
+    items = re.findall(r"<BaseURL>(.+?)</BaseURL>", data['dash_manifest'])
+    data['uri'] = html.unescape(items[0]) if items else None
     return Track(**data)
